@@ -5,15 +5,21 @@
 #' equivalent to.
 #'
 #' @param mix Prior (mixture of conjugate distributions).
-#' @param method Selects the used method. Can be either \code{elir} (default), \code{moment} or \code{morita}.
-# @param s For \code{morita} method large constant to ensure that the prior scaled by this value is vague (default 100); see Morita et al. (2008) for details.
+#' @param method Selects the used method. Can be either \code{elir}
+#'     (default), \code{moment} or \code{morita}.
+# @param s For \code{morita} method large constant to ensure that the
+#     prior scaled by this value is vague (default 100); see Morita
+#     et al. (2008) for details.
+# @param eps Probability mass left out from the numerical integration
+#     of the expected information for the Poisson-Gamma case of
+#     Morita method (defaults to 1E-4).
+# @param sigma reference scale.
 #' @param ... Optional arguments applicable to specific methods.
 #'
 #' @details The ESS is calculated using either the expected local
 #'     information ratio (elir) \emph{Neuenschwander et
 #'     al. (submitted)}, the moments approach or the method by
-#'     \emph{Morita et al. (2008)}. The moments based method is the
-#'     default method and provides conservative estimates of the ESS.
+#'     \emph{Morita et al. (2008)}.
 #'
 #' The elir approach is the only ESS which fulfills predictive
 #' consistency. The predictive consistency of the ESS requires that
@@ -21,8 +27,9 @@
 #' a fixed amount of events over the prior predictive distribution
 #' from which the number of forward simulated events is
 #' subtracted. The elir approach results in ESS estimates which are
-#' neither conservative nor liberal. See the example section for a
-#' demonstration of predictive consistency.
+#' neither conservative nor liberal whereas the moments method yields
+#' conservative and the morita method liberal results. See the example
+#' section for a demonstration of predictive consistency.
 #'
 #' For the moments method the mean and standard deviation of the
 #' mixture are calculated and then approximated by the conjugate
@@ -33,7 +40,12 @@
 #' The Morita method used here evaluates the mixture prior at the mode
 #' instead of the mean as proposed originally by Morita. The method
 #' may lead to very optimistic ESS values, especially if the mixture
-#' contains many components.
+#' contains many components. The calculation of the Morita approach
+#' here follows the approach presented in Neuenschwander B. et all
+#' (2019) which avoids the need for a minimization and does not
+#' restrict the ESS to be an integer.
+#'
+#' @return Returns the ESS of the prior as floating point number.
 #'
 #' @template conjugate_pairs
 #'
@@ -43,7 +55,7 @@
 #'
 #' @references Neuenschwander B, Weber S, Schmidli H, O'Hagen A.
 #' Predictively Consistent Prior Effective Sample Sizes.
-#' \emph{submitted}
+#' \emph{pre-print} 2019; arXiv:1907.04185
 #'
 #' @examples
 #' # Conjugate Beta example
@@ -72,7 +84,7 @@
 #' ess(bmix, method="morita")
 #'
 #' # Predictive consistency of elir
-#' \dontrun{
+#' \donttest{
 #' n_forward <- 1E2
 #' bmixPred <- preddist(bmix, n=n_forward)
 #' pred_samp <- rmix(bmixPred, 1E3)
@@ -104,7 +116,7 @@
 #' @export
 ess <- function(mix, method=c("elir", "moment", "morita"), ...) UseMethod("ess")
 #' @export
-ess.default <- function(mix, method=c("elir", "moment", "morita"), ...) "Unknown density"
+ess.default <- function(mix, method=c("elir", "moment", "morita"), ...) stop("Unknown density")
 
 
 calc_loc <- function(mix, loc=c("mode", "median", "mean")) {
@@ -113,8 +125,11 @@ calc_loc <- function(mix, loc=c("mode", "median", "mean")) {
         tol <- .Machine$double.eps^0.25
         locEst <- mixmode(mix)
 
-        if(length(attr(locEst, "modes")) > 1)
+        if(length(attr(locEst, "modes")) > 1) {
             warning("Detected multiple modes.\nThe ESS is determined for the largest mode, but ESS concept is ill-defined for multi-modal distributions.")
+        } else {
+            attr(locEst, "modes") <- NULL
+        }
     }
     if(loc == "median") {
         locEst <- qmix(mix, 0.5)
@@ -123,7 +138,8 @@ calc_loc <- function(mix, loc=c("mode", "median", "mean")) {
         locEst <- summary(mix, NULL)["mean"]
     }
     names(locEst) <- NULL
-    return(locEst)
+
+    return(unname(locEst))
 }
 ## function to calculate mixture info of arbitrary density; input
 ## needed is the density function, gradient and hessian of the log
@@ -177,7 +193,7 @@ weighted_lir <- function(mix, info, fisher_inverse) {
 # based on
 # Morita, Thall, Mueller (MTM) 2008 Biometrics
 # only difference: evaluated at mode of prior rather than at mean; and the flattened prior are derived with respect to the scale of 1 instead of being relative to the input scale
-# SW: speedup by using analytical results and use of bisectioning search
+#' @describeIn ess
 #' @export
 ess.betaMix <- function(mix, method=c("elir", "moment", "morita"), ..., s=100) {
 
@@ -191,7 +207,7 @@ ess.betaMix <- function(mix, method=c("elir", "moment", "morita"), ..., s=100) {
     ## simple and conservative moment matching
     if(method == "moment") {
         smix <- summary(mix)
-        res <- round(sum(ms2beta(smix["mean"], smix["sd"])))
+        res <- sum(ms2beta(smix["mean"], smix["sd"]))
         names(res) <- NULL
         return( res )
     }
@@ -209,6 +225,8 @@ ess.betaMix <- function(mix, method=c("elir", "moment", "morita"), ..., s=100) {
     alphaP0 <- locEst / s
     betaP0 <- (1-locEst) / s
 
+    info.prior0 <- betaInfo(locEst, alphaP0, betaP0)
+
     ## MTM paper would follow this:
     ##priorN <- sum(mix[1,] * (alphaP + betaP))
     ##alphaP0 <- mode * priorN / s
@@ -226,15 +244,19 @@ ess.betaMix <- function(mix, method=c("elir", "moment", "morita"), ..., s=100) {
         ## negative 2nd log-derivative at mode
         info <- betaInfo(locEst, alphaP0 + yn, betaP0 + m - yn)
         ## prior predictive
-        sum(info * dmix(preddist(mix,m), yn) )
+        sum(info * dmix(preddist(mix,n=m), yn) )
     }
-
     ## function to search for change of sign
     ed2pDiff <- function(m) {
         deriv2.prior - ed2p(m)
     }
 
-    return(unname(uniroot_int(ed2pDiff, c(0,ESSmax))))
+    pd0 <- dmix(preddist(mix, n=1), 0)
+    Einfo <- binomialInfo(0,locEst,1) * pd0 + binomialInfo(1,locEst,1) * (1-pd0)
+
+    ##return(unname(uniroot_int(ed2pDiff, c(0,ESSmax))))
+    ## Eq. 9 of Neuenschwander et al. (2019)
+    return( unname((deriv2.prior - info.prior0) / Einfo ) )
 }
 
 ## derivative of a single log-beta
@@ -266,9 +288,16 @@ bernoulliFisherInfo_inverse <- function(x) {
     x - x^2
 }
 
+## info metric for a binomial, second derivative wrt to theta of the
+## log binomial
+binomialInfo <- function(r,theta,n) {
+    r / theta^2 + (n-r)/(1-theta)^2
+}
 
+
+#' @describeIn ess
 #' @export
-ess.gammaMix <- function(mix, method=c("elir", "moment", "morita"), s=100, ...) {
+ess.gammaMix <- function(mix, method=c("elir", "moment", "morita"), ..., s=100, eps=1E-4) {
 
     method <- match.arg(method)
     lik <- likelihood(mix)
@@ -286,9 +315,9 @@ ess.gammaMix <- function(mix, method=c("elir", "moment", "morita"), s=100, ...)
         coef <- ms2gamma(smix["mean"], smix["sd"])
         names(coef) <- NULL
         if(lik == "poisson")
-            return(unname(round(coef[2])))
+            return(unname(coef[2]))
         if(lik == "exp")
-            return(unname(round(coef[1])))
+            return(unname(coef[1]))
         stop("Unkown likelihood")
     }
 
@@ -308,6 +337,14 @@ ess.gammaMix <- function(mix, method=c("elir", "moment", "morita"), s=100, ...)
         }
 
         ESSmax <- ceiling(sum(mix[3,])) * 2
+
+        info.prior0  <- gammaInfo(locEst, locEst/s, 1/s)
+
+        ## E_Y1 ( i_F ) using numerical integration
+        pred_pmf <- preddist(mix, n=1)
+        lim <- qmix(pred_pmf, c(eps/2, 1-eps/2))
+        y1 <- seq(lim[1], lim[2])
+        Einfo <- sum(dmix(pred_pmf, y1) * poissonInfo(y1, locEst))
     }
 
     if(lik == "exp") {
@@ -318,13 +355,18 @@ ess.gammaMix <- function(mix, method=c("elir", "moment", "morita"), s=100, ...)
         }
 
         ESSmax <- ceiling(sum(mix[2,])) * 2
+
+        info.prior0  <- gammaInfo(locEst, 1/s, 1/(s*locEst))
+
+        ## E_Y1 ( i_F ) (the i_F does not depend on the data)
+        Einfo  <- expInfo(1,locEst)
     }
 
     if(any(priorN < 10/s )) {
         warning("Some of the mixture components have a scale which is large compared to the rescaling factor s. Consider increasing s.")
     }
 
-    return(unname(uniroot_int(ed2pDiff, c(0,ESSmax))))
+    return(unname( (deriv2.prior - info.prior0)/Einfo ) )
 }
 
 ## respective functions for the gamma distribution
@@ -346,10 +388,17 @@ poissonFisherInfo_inverse <- function(x) {
 expFisherInfo_inverse <- function(x) {
     x^2
 }
+poissonInfo <- function(y,theta) {
+    y/theta^2
+}
+expInfo <- function(y,theta) {
+    1/theta^2
+}
 
 
+#' @describeIn ess
 #' @export
-ess.normMix <- function(mix, method=c("elir", "moment", "morita"), sigma, s=100, ...) {
+ess.normMix <- function(mix, method=c("elir", "moment", "morita"), ..., sigma, s=100) {
 
     method <- match.arg(method)
 
@@ -372,7 +421,7 @@ ess.normMix <- function(mix, method=c("elir", "moment", "morita"), sigma, s=100,
     ## simple and conservative moment matching
     if(method == "moment") {
         smix <- summary(mix)
-        res <- round(tauSq / smix["sd"]^2)
+        res <- tauSq / smix["sd"]^2
         return( unname(res) )
     }
 
@@ -392,7 +441,11 @@ ess.normMix <- function(mix, method=c("elir", "moment", "morita"), sigma, s=100,
         deriv2.prior - normInfo(locEst, muP0, sqrt(1/(m/tauSq + 1/sigmaP0Sq)))
     }
 
-    return(unname(uniroot_int(ed2pDiff, c(0,ESSmax))))
+    info.prior0  <- normInfo(locEst, muP0, sqrt(sigmaP0Sq))
+
+    Einfo  <- 1/tauSq
+
+    return(unname( (deriv2.prior - info.prior0)/Einfo ))
 }
 
 ## derivative of a single log-normal
